<?php
function _updatePrefs(&$tof,$vars) {
	$user = array(
		'Name'=>$vars['Name'],
		'Email'=>$vars['Email'],
		'PictureSize'=>$vars['PictureSize'],
		'PictureInterval'=>$vars['PictureInterval'],
		'NotifyComment'=>isset($vars['NotifyComment']));

	if ($vars['Password'] != $vars['ConfirmPassword']) {
		$tof->error(_("Password and ConfirmPassword are different."));
		$tof->error(_("Password not updated."));
	} else {
		$user['Password'] = $vars['Password'];
		$tof->ct->updateUser($tof->uid,$user);
		$tof->user = $tof->ct->getUser($tof->uid);
	}
}
?>